==> qmmp_0.3.1.orig.tar.gz: qmmp-0.3.1/src/plugins/Visual/projectm/projectmplugin.h <==
/***************************************************************************
 *   Copyright (C) 2009 by Ilya Kotov                                      *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROJECTMPLUGIN_H
#define PROJECTMPLUGIN_H

#include <QWidget>
#include <qmmp/visual.h>
#include <qmmp/constants.h>

class QTimer;
class Buffer;
class ProjectMWidget;

class ProjectMPlugin : public Visual
{
    Q_OBJECT

public:
    ProjectMPlugin(QWidget *parent = 0);
    virtual ~ProjectMPlugin();

    void add(Buffer *, unsigned long, int, int);
    void clear();

private:
    QTimer *m_timer;
    ProjectMWidget *m_projectMWidget;
};


#endif

==> qmmp_0.5.2.orig.tar.gz: qmmp-0.5.2/src/plugins/Visual/projectm/projectmplugin.h <==
/***************************************************************************
 *   Copyright (C) 2009-2010 by Ilya Kotov                                 *
 *   forkotov02@hotmail.ru                                                 *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PROJECTMPLUGIN_H
#define PROJECTMPLUGIN_H

#include <QWidget>
#include <qmmp/visual.h>

class QTimer;
class Buffer;
class ProjectMWidget;

class ProjectMPlugin : public Visual
{
    Q_OBJECT

public:
    ProjectMPlugin(QWidget *parent = 0);
    virtual ~ProjectMPlugin();

    void add(unsigned char *data, qint64 size, int chan);
    void clear();

private:
    QTimer *m_timer;
    ProjectMWidget *m_projectMWidget;
};


#endif
